.lb-item[data-v-85c8d1e2]{width:258px;margin:10px;border:1px solid #ddd}.lb-item[data-v-064e64b4]{border:1px solid #fff}h1[data-v-381958bf]{text-align:center;font-size:1.3em}.lb-warning[data-v-381958bf]{color:orange;font-size:2em;margin-top:30px;text-align:center}.lb-picker[data-v-381958bf]{font-weight:700}.lb-button-on[data-v-381958bf]{color:#00f}.lb-button-off[data-v-381958bf]{color:#bbb}.lb-button-off[data-v-381958bf],.lb-button-on[data-v-381958bf]{width:45px;font-size:1.3em}.lb-current{margin-top:35px}