.lb-documentation[data-v-4f29ece6]{font-size:1.4em}.toc[data-v-4f29ece6]{font-size:18px;color:#ccc;float:left;width:300px;position:absolute;top:0;left:0;margin:20px 0 0 5px}.content[data-v-4f29ece6]{width:100%;height:100vh;overflow-x:hidden;overflow-y:auto;margin-top:30px}h2[data-v-4f29ece6]{font-size:42px;clear:both;text-align:left;margin-left:400px;padding-top:40px}h3[data-v-4f29ece6]{clear:both;text-align:center;font-size:1.1em}p[data-v-4f29ece6]{width:55%;margin:0 auto;text-align:justify}.lb-architecture[data-v-4f29ece6]{text-align:center}.lb-img-archi[data-v-4f29ece6]{float:right;margin-right:90px}.lb-code[data-v-4f29ece6]{color:#eee;background:#333;padding:5px;font-weight:700;border-radius:2px;border:1px solid #555;font-family:monospace}.lb-controls[data-v-4f29ece6]{float:right;width:350px;max-height:550px;overflow-x:hidden;overflow-y:hidden;scrollbar-color:auto;padding-right:10px;text-align:center}.lb-img-center[data-v-4f29ece6]{text-align:center}.list-inline[data-v-4f29ece6]{list-style:none;padding:0}.list-inline>li[data-v-4f29ece6]{display:inline;color:#ccc;background:#333;width:20px;margin:5px;padding:5px}.lb-topbar[data-v-4f29ece6]{margin-left:40px}.lb-exercises[data-v-4f29ece6]{list-style:none}.lb-exercise[data-v-4f29ece6]{border:2px solid #eee;margin:1em;cursor:none}.lb-solution[data-v-4f29ece6]{display:grid;grid-template-columns:100px auto 150px;align-items:start;margin:0 610px 0 620px}.lb-sequence[data-v-4f29ece6]{text-align:left}