.lb-explorer-container{width:100%;background:url(../img/lb-stripe.png),linear-gradient(#222,#111)}.lb-explorer{margin-top:30px;display:grid;grid-template-columns:505px 1fr;grid-gap:20px}.lb-warning{color:orange;font-size:2em;grid-column:1/4;text-align:center}.lb-volume{margin-top:20px;margin-right:auto;margin-left:auto;width:400px}#slider{margin-top:10px}.lb-plugins{border:1px solid #333;border-radius:8px;padding:1em;margin-left:20px}.lb-demos-list{overflow-y:scroll;height:200px}.lb-demo{font-size:1.2em}.lb-preview{text-align:center}.lb-sequence{text-align:left}.lb-value{position:relative;top:24px;padding:0;text-shadow:0 0 2px #000}.lb-plugin-container{display:grid;grid-template-columns:400px 1fr}.lb-plugin-description{font-size:1.5em}